@@ -4,8 +4,9 @@ use serde::{Deserialize, Serialize};
 
 #[cfg(feature = "non_critical_lints")]
 use crate::rules::non_critical_lints::{
-    dot_notation::DotNotationConfig, eqeqeq::EqeqeqConfig, no_console::NoConsoleConfig,
-    no_restricted_syntax::NoRestrictedSyntaxConfig, no_use_before_define::NoUseBeforeDefineConfig,
+    dot_notation::DotNotationConfig, eqeqeq::EqeqeqConfig, no_bitwise::NoBitwiseConfig,
+    no_console::NoConsoleConfig, no_restricted_syntax::NoRestrictedSyntaxConfig,
+    no_use_before_define::NoUseBeforeDefineConfig,
     prefer_regex_literals::PreferRegexLiteralsConfig, quotes::QuotesConfig,
 };
 
@@ -112,4 +113,8 @@ pub struct LintConfig {
     #[cfg(feature = "non_critical_lints")]
     #[serde(default, alias = "noRestrictedSyntax")]
     pub no_restricted_syntax: RuleConfig<NoRestrictedSyntaxConfig>,
+
+    #[cfg(feature = "non_critical_lints")]
+    #[serde(default, alias = "noBitwise")]
+    pub no_bitwise: RuleConfig<NoBitwiseConfig>,
 }
