@@ -18,6 +18,7 @@ pub(crate) mod non_critical_lints {
     pub mod dot_notation;
     pub mod eqeqeq;
     pub mod no_alert;
+    pub mod no_bitwise;
     pub mod no_console;
     pub mod no_debugger;
     pub mod no_empty_pattern;
@@ -101,6 +102,8 @@ pub fn all(lint_params: LintParams) -> Vec<Box<dyn Rule>> {
         rules.extend(no_restricted_syntax::no_restricted_syntax(
             &lint_config.no_restricted_syntax,
         ));
+
+        rules.extend(no_bitwise::no_bitwise(&lint_config.no_bitwise));
     }
 
     rules
